+++ SKBookmarkController.h	(working copy)
@@ -69,7 +69,9 @@
 - (IBAction)deleteBookmark:(id)sender;
 - (IBAction)toggleStatusBar:(id)sender;
 
-- (void)addRecentDocumentForURL:(NSURL *)fileURL pageIndex:(NSUInteger)pageIndex snapshots:(NSArray *)setups;
+- (void)addRecentDocumentForURL:(NSURL *)fileURL pageIndex:(NSUInteger)pageIndex displayMode:(PDFDisplayMode)displayMode displaysAsBook:(BOOL)displaysAsBook snapshots:(NSArray *)setups;
+- (NSUInteger)displayModeForRecentDocumentAtURL:(NSURL *)fileURL;
+- (NSUInteger)displaysAsBookForRecentDocumentAtURL:(NSURL *)fileURL;
 - (NSUInteger)pageIndexForRecentDocumentAtURL:(NSURL *)fileURL;
 - (NSArray *)snapshotsForRecentDocumentAtURL:(NSURL *)fileURL;
 
Index: SKBookmarkController.m
===================================================================
--- SKBookmarkController.m	(revision 8163)
+++ SKBookmarkController.m	(working copy)
@@ -69,6 +69,8 @@
 #define RECENTDOCUMENTS_KEY @"recentDocuments"
 
 #define PAGEINDEX_KEY @"pageIndex"
+#define BOOKMODE_KEY  @"displayAsBook"
+#define DISPLAYMODE_KEY    @"displayMode"
 #define ALIAS_KEY     @"alias"
 #define ALIASDATA_KEY @"_BDAlias"
 #define SNAPSHOTS_KEY @"snapshots"
@@ -233,7 +235,7 @@
     return nil;
 }
 
-- (void)addRecentDocumentForURL:(NSURL *)fileURL pageIndex:(NSUInteger)pageIndex snapshots:(NSArray *)setups {
+- (void)addRecentDocumentForURL:(NSURL *)fileURL pageIndex:(NSUInteger)pageIndex displayMode:(PDFDisplayMode)displayMode displaysAsBook:(BOOL)displaysAsBook snapshots:(NSArray *)setups {
     if (fileURL == nil)
         return;
     
@@ -243,13 +245,28 @@
     
     SKAlias *alias = [SKAlias aliasWithURL:fileURL];
     if (alias) {
-        NSMutableDictionary *bm = [NSMutableDictionary dictionaryWithObjectsAndKeys:[NSNumber numberWithUnsignedInteger:pageIndex], PAGEINDEX_KEY, [alias data], ALIASDATA_KEY, alias, ALIAS_KEY, [setups count] ? setups : nil, SNAPSHOTS_KEY, nil];
+        NSMutableDictionary *bm = [NSMutableDictionary dictionaryWithObjectsAndKeys:[NSNumber numberWithUnsignedInteger:pageIndex], PAGEINDEX_KEY, [NSNumber numberWithUnsignedInteger:displayMode], DISPLAYMODE_KEY, [NSNumber numberWithUnsignedInteger:displaysAsBook], BOOKMODE_KEY, [alias data], ALIASDATA_KEY, alias, ALIAS_KEY, [setups count] ? setups : nil, SNAPSHOTS_KEY, nil];
         [recentDocuments insertObject:bm atIndex:0];
         if ([recentDocuments count] > maxRecentDocumentsCount)
             [recentDocuments removeLastObject];
     }
 }
 
+
+- (NSUInteger)displayModeForRecentDocumentAtURL:(NSURL *)fileURL {
+    if (fileURL == nil)
+        return NSNotFound;
+    NSNumber *displayMode = [[self recentDocumentInfoAtURL:fileURL] objectForKey:DISPLAYMODE_KEY];
+    return displayMode == nil ? NSNotFound : [displayMode unsignedIntegerValue];
+}
+
+- (NSUInteger)displaysAsBookForRecentDocumentAtURL:(NSURL *)fileURL {
+    if (fileURL == nil)
+        return NSNotFound;
+    NSNumber *displaysAsBook = [[self recentDocumentInfoAtURL:fileURL] objectForKey:BOOKMODE_KEY];
+    return displaysAsBook == nil ? NSNotFound : [displaysAsBook unsignedIntegerValue];
+}
+
 - (NSUInteger)pageIndexForRecentDocumentAtURL:(NSURL *)fileURL {
     if (fileURL == nil)
         return NSNotFound;
Index: SKMainDocument.m
===================================================================
--- SKMainDocument.m	(revision 8163)
+++ SKMainDocument.m	(working copy)
@@ -269,8 +269,11 @@
 - (void)saveRecentDocumentInfo {
     NSURL *fileURL = [self fileURL];
     NSUInteger pageIndex = [[[self pdfView] currentPage] pageIndex];
+    PDFDisplayMode displayMode = [[self pdfView] displayMode];
+    BOOL displaysAsBook = [[self pdfView] displaysAsBook];
+    
     if (fileURL && pageIndex != NSNotFound && [self mainWindowController])
-        [[SKBookmarkController sharedBookmarkController] addRecentDocumentForURL:fileURL pageIndex:pageIndex snapshots:[[[self mainWindowController] snapshots] valueForKey:SKSnapshotCurrentSetupKey]];
+        [[SKBookmarkController sharedBookmarkController] addRecentDocumentForURL:fileURL pageIndex:pageIndex displayMode:displayMode displaysAsBook:displaysAsBook snapshots:[[[self mainWindowController] snapshots] valueForKey:SKSnapshotCurrentSetupKey]];
 }
 
 - (SKInteractionMode)systemInteractionMode {
Index: SKMainWindowController.m
===================================================================
--- SKMainWindowController.m	(revision 8163)
+++ SKMainWindowController.m	(working copy)
@@ -462,6 +462,35 @@
         }
     }
     
+    // Set display as book
+    NSUInteger displayAsBook = NSNotFound;
+    if (hasWindowSetup)
+        displayAsBook = [[savedNormalSetup objectForKey:DISPLAYSASBOOK_KEY] boolValue];
+    else if ([sud boolForKey:SKRememberLastPageViewedKey])
+        displayAsBook = [[SKBookmarkController sharedBookmarkController] displaysAsBookForRecentDocumentAtURL:[[self document] fileURL]];
+    if (displayAsBook != NSNotFound) {
+        if ([[pdfView document] isLocked]) {
+            [savedNormalSetup setObject:[NSNumber numberWithBool:displayAsBook] forKey:DISPLAYSASBOOK_KEY];
+        } else {
+            [pdfView setDisplaysAsBook:[[NSNumber numberWithBool:displayAsBook] boolValue]];
+        }
+    }
+    
+    // Set display mode
+    NSUInteger displayMode = NSNotFound;
+    if (hasWindowSetup)
+        displayMode = [[savedNormalSetup objectForKey:DISPLAYMODE_KEY] unsignedIntegerValue];
+    else if ([sud boolForKey:SKRememberLastPageViewedKey])
+        displayMode = [[SKBookmarkController sharedBookmarkController] displayModeForRecentDocumentAtURL:[[self document] fileURL]];
+    if (displayMode != NSNotFound) {
+        if ([[pdfView document] isLocked]) {
+            [savedNormalSetup setObject:[NSNumber numberWithUnsignedInteger:displayMode] forKey:DISPLAYMODE_KEY];
+        } else {
+            [pdfView setDisplayMode:[[NSNumber numberWithUnsignedInteger:displayMode] unsignedIntegerValue]];
+        }
+    }
+
+    
     // We can fit only after the PDF has been loaded
     if (windowSizeOption == SKFitWindowOption && hasWindowSetup == NO)
         [self performFit:self];
